@@ -11,17 +11,19 @@
 #define AI__AI_H
 
 #include "sea.h"
+#include "ships.h"
 
 class AI
 {
 protected:
     Sea::Player m_player;
     Sea* m_sea;
+    const BattleShipsConfiguration* m_config;
 public:
-    AI(Sea::Player player, Sea* sea);
+    AI(Sea::Player player, Sea* sea, const BattleShipsConfiguration* config);
     virtual ~AI() { }
     virtual Coord getMove() = 0;
-    virtual void setShips() = 0;
+    virtual void setShips();
     virtual void notify(Sea::Player player, const Coord& c, const HitInfo& hit) = 0;
     Coord desperateMove() const;
 };
